
/*
This do-file is a template to create  summary and balance tables using Stata.
The current structure create a basic balance table with two panels.
It can easily be ammended to contain other statistics instead of differences in means.
The structure is based on original code by John de Quidt.
*/
use  "data.dta" , clear 


* Step 1: Label variables with the text you want to appear in the table *

label var female "Female"
label var age "Age"
label var exp "Work experience"
label var vocational "Vocational education"
label var university "University education"

* Step  2: Create variables that indicate empty lines or Panel headings *

*Empty line
gen empt1=.
label var empt1 " "
gen empt2=.
label var empt2 " "

*Panel A

gen pana = .
label var pana "\textbf{Pooled} \\" // Note that you can use Latex code in the tables. The '\\' adds an additional empty line below the panel heading.

gen panb = .
label var panb "\textbf{Women} \\" //


* Step 3: Create conditional variables to be used in panels

* I want panel b to be women only. I create conditonal variables for this.

local temp_var " " //Local capturing variables to be deleted after this code


foreach x in age exp vocational university {
clonevar  `x'b= `x' if female==1 // Use clonevar instead of gen to preserve label

local temp_var = "`temp_var' `x'b"
}

* Step 4: Full list of covariates (including temporary ones in the desired order) *
loc covars "pana female age exp vocational university empt1 panb ageb expb vocationalb universityb empt2"


* Step 5: Choose number of columns in table (which statistics do you want to display).

	local number_columns= 4 // This determines the number of columns (4 in this case).
	
	
/* This creates empty regression results for each column */

*No need to touch this code*
qui {
    preserve
	
    clear all
    eststo clear
    estimates drop _all

    set obs 10
    qui gen x = 1
    qui gen y = 1

    forval i = 1/`number_columns' { 
        qui eststo col`i': reg x y
    }
    restore
	}
******************************************************************	
	

	
* Step 6: Define table headings

    loc colnames ""Treatment mean" "Control mean" "\Delta" "p-value(Treatment = Control)" "

*Define empty locals for labels and outout - no need to change
    loc rowstats ""
    loc rowlabels ""


* Step 7: Add statistics to regression results

	
    foreach var in `covars' { // Loop over all covariates
	
	
	qui sum `var'   // Check if variable is non-empty
	if `r(N)'==0 {
	estadd loc `var'_m = " ": col1 // Ensure that the estimation result exists 
	}
	if `r(N)'!=0 { // Only continue if variable non-empty

/* Here you need to choose what statistics you want to be displayed in the table. 
This can include regression coefficients, summary statistics,  p-values, or strings.
*/
		* Add summary statistic
       qui {
            qui sum `var'  if treatment ==1
            estadd loc `var'_m = string(r(mean), "%9.2f"): col1   // %9.2f determines the decimals displayed
        }

        qui {
            qui sum `var' if treatment ==0
            estadd loc `var'_m = string(r(mean), "%9.2f"): col2 // col2  determines in which column this statistics is placed
        }
		
		* Add regression coefficients
		qui {
            qui reg `var' treatment , robust
            estadd loc `var'_m = string(_b[treatment], "%9.2f"): col3
        }
		
		* Add p-values
        qui {
            qui reg `var' treatment , robust
            qui test treatment = 0	// This is an easy way to obtain p-values after an regression.
            estadd loc `var'_m = string(r(p), "%9.3f"): col4
        }

		}
        loc rowstats "`rowstats' `var'_m " // This statistics to the rowstats local which contains all statistics to be included in the table.
        loc rowlabels "`rowlabels' `"`: var la `var''"' " " " // This add labels to the rowlabels local
	}
	
/*
Step 7.1: Add numer of observations at the bottom of the table (below any column).
This is manually to only contain values in the first two columns but not the other ones.

*/
	
	        cap noi {
            qui sum treatment  if treatment ==1
            estadd loc numobs = string(r(N), "%9.0f"): col1  
        }

        cap noi {
            qui sum treatment if treatment ==0
            estadd loc numobs  = string(r(N), "%9.0f"): col2
		}
		loc rowstats "`rowstats' numobs " // Note that this is adjusted to num
        loc rowlabels "`rowlabels'  "Number of Observations" " " " 
		
		
 
* Step 8: Produce outputs (only need to adjust the output path)

    esttab * using "balance.tex", replace cells(none) booktabs nonotes //
	nonum compress alignment(c) nogap noobs nobaselevels label mtitle(`colnames') stats(`rowstats', labels(`rowlabels'))

* Drop temporarily stored variables (no need to change)
    eststo clear
	drop ` temp_var'



